==> eks-1.93.0-sources.jar: software/amazon/awscdk/services/eks/KubernetesPatch.java <==
package software.amazon.awscdk.services.eks;

/**
 * A CloudFormation resource which applies/restores a JSON patch into a Kubernetes resource.
 * <p>
 * @see https://kubernetes.io/docs/tasks/run-application/update-api-object-kubectl-patch/
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:47:08.083Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.eks.$Module.class, fqn = "@aws-cdk/aws-eks.KubernetesPatch")
public class KubernetesPatch extends software.amazon.awscdk.core.Construct {

    protected KubernetesPatch(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected KubernetesPatch(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public KubernetesPatch(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.eks.KubernetesPatchProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.eks.KubernetesPatch}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.eks.KubernetesPatch> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.eks.KubernetesPatchProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.eks.KubernetesPatchProps.Builder();
        }

        /**
         * The JSON object to pass to `kubectl patch` when the resource is created/updated.
         * <p>
         * @return {@code this}
         * @param applyPatch The JSON object to pass to `kubectl patch` when the resource is created/updated. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder applyPatch(final java.util.Map<java.lang.String, ? extends java.lang.Object> applyPatch) {
            this.props.applyPatch(applyPatch);
            return this;
        }

        /**
         * The cluster to apply the patch to.
         * <p>
         * [disable-awslint:ref-via-interface]
         * <p>
         * @return {@code this}
         * @param cluster The cluster to apply the patch to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cluster(final software.amazon.awscdk.services.eks.ICluster cluster) {
            this.props.cluster(cluster);
            return this;
        }

        /**
         * The full name of the resource to patch (e.g. `deployment/coredns`).
         * <p>
         * @return {@code this}
         * @param resourceName The full name of the resource to patch (e.g. `deployment/coredns`). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder resourceName(final java.lang.String resourceName) {
            this.props.resourceName(resourceName);
            return this;
        }

        /**
         * The JSON object to pass to `kubectl patch` when the resource is removed.
         * <p>
         * @return {@code this}
         * @param restorePatch The JSON object to pass to `kubectl patch` when the resource is removed. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder restorePatch(final java.util.Map<java.lang.String, ? extends java.lang.Object> restorePatch) {
            this.props.restorePatch(restorePatch);
            return this;
        }

        /**
         * The patch type to pass to `kubectl patch`.
         * <p>
         * The default type used by <code>kubectl patch</code> is "strategic".
         * <p>
         * Default: PatchType.STRATEGIC
         * <p>
         * @return {@code this}
         * @param patchType The patch type to pass to `kubectl patch`. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder patchType(final software.amazon.awscdk.services.eks.PatchType patchType) {
            this.props.patchType(patchType);
            return this;
        }

        /**
         * The kubernetes API namespace.
         * <p>
         * Default: "default"
         * <p>
         * @return {@code this}
         * @param resourceNamespace The kubernetes API namespace. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder resourceNamespace(final java.lang.String resourceNamespace) {
            this.props.resourceNamespace(resourceNamespace);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.eks.KubernetesPatch}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.eks.KubernetesPatch build() {
            return new software.amazon.awscdk.services.eks.KubernetesPatch(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> eks-1.182.0-sources.jar: software/amazon/awscdk/services/eks/KubernetesPatch.java <==
package software.amazon.awscdk.services.eks;

/**
 * A CloudFormation resource which applies/restores a JSON patch into a Kubernetes resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Cluster cluster;
 * KubernetesPatch.Builder.create(this, "hello-kub-deployment-label")
 *         .cluster(cluster)
 *         .resourceName("deployment/hello-kubernetes")
 *         .applyPatch(Map.of("spec", Map.of("replicas", 5)))
 *         .restorePatch(Map.of("spec", Map.of("replicas", 3)))
 *         .build();
 * </pre></blockquote>
 * <p>
 * @see <a href="https://kubernetes.io/docs/tasks/run-application/update-api-object-kubectl-patch/">https://kubernetes.io/docs/tasks/run-application/update-api-object-kubectl-patch/</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:46.744Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.eks.$Module.class, fqn = "@aws-cdk/aws-eks.KubernetesPatch")
public class KubernetesPatch extends software.amazon.awscdk.core.Construct {

    protected KubernetesPatch(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected KubernetesPatch(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public KubernetesPatch(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.eks.KubernetesPatchProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.eks.KubernetesPatch}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.eks.KubernetesPatch> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.eks.KubernetesPatchProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.eks.KubernetesPatchProps.Builder();
        }

        /**
         * The JSON object to pass to `kubectl patch` when the resource is created/updated.
         * <p>
         * @return {@code this}
         * @param applyPatch The JSON object to pass to `kubectl patch` when the resource is created/updated. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder applyPatch(final java.util.Map<java.lang.String, ? extends java.lang.Object> applyPatch) {
            this.props.applyPatch(applyPatch);
            return this;
        }

        /**
         * The cluster to apply the patch to.
         * <p>
         * [disable-awslint:ref-via-interface]
         * <p>
         * @return {@code this}
         * @param cluster The cluster to apply the patch to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cluster(final software.amazon.awscdk.services.eks.ICluster cluster) {
            this.props.cluster(cluster);
            return this;
        }

        /**
         * The full name of the resource to patch (e.g. `deployment/coredns`).
         * <p>
         * @return {@code this}
         * @param resourceName The full name of the resource to patch (e.g. `deployment/coredns`). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder resourceName(final java.lang.String resourceName) {
            this.props.resourceName(resourceName);
            return this;
        }

        /**
         * The JSON object to pass to `kubectl patch` when the resource is removed.
         * <p>
         * @return {@code this}
         * @param restorePatch The JSON object to pass to `kubectl patch` when the resource is removed. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder restorePatch(final java.util.Map<java.lang.String, ? extends java.lang.Object> restorePatch) {
            this.props.restorePatch(restorePatch);
            return this;
        }

        /**
         * The patch type to pass to `kubectl patch`.
         * <p>
         * The default type used by <code>kubectl patch</code> is "strategic".
         * <p>
         * Default: PatchType.STRATEGIC
         * <p>
         * @return {@code this}
         * @param patchType The patch type to pass to `kubectl patch`. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder patchType(final software.amazon.awscdk.services.eks.PatchType patchType) {
            this.props.patchType(patchType);
            return this;
        }

        /**
         * The kubernetes API namespace.
         * <p>
         * Default: "default"
         * <p>
         * @return {@code this}
         * @param resourceNamespace The kubernetes API namespace. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder resourceNamespace(final java.lang.String resourceNamespace) {
            this.props.resourceNamespace(resourceNamespace);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.eks.KubernetesPatch}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.eks.KubernetesPatch build() {
            return new software.amazon.awscdk.services.eks.KubernetesPatch(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
